---
hide-toc: true
---

```{include} README.md
---
end-before: <!-- toc-start -->
---
```

```{include} README.md
---
start-after: <!-- toc-end -->
---
```

```{toctree}
:hidden:

🏠 Home <self>
🚀 Usage tutorial <tutorial>
❓ FAQ <faq>
```

```{toctree}
:hidden:
:maxdepth: 2

🛠️ API reference <reference/index>
```
